==> keyclic_sdk_api-1.28.0.tar.gz: lib/api/relationship_api.dart <==
part of keyclic_sdk_api.api;



class RelationshipApi {
  final ApiClient apiClient;

  RelationshipApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Retrieve all Relationship resources.
  ///
  /// 
  Future<OrganizationPagination> cgetRelationshipsByOrganization(String xKeyclicApp, String organization, { String acceptLanguage, String xKeyclicAppVersion, String businessActivity, String geoCoordinates, String geoPoint, int page, int limit, String order, DateTime after, DateTime before, String search[alternateName], String search[billingEmailAddress], String search[description], String search[name], String search[notificationEmailAddress] }) async {
    Object postBody = null;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(businessActivity != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "business_activity", businessActivity));
    }
    if(geoCoordinates != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "geo_coordinates", geoCoordinates));
    }
    if(geoPoint != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "geo_point", geoPoint));
    }
    if(page != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(order != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "order", order));
    }
    if(after != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "after", after));
    }
    if(before != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "before", before));
    }
    if(search[alternateName] != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[alternateName]", search[alternateName]));
    }
    if(search[billingEmailAddress] != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[billingEmailAddress]", search[billingEmailAddress]));
    }
    if(search[description] != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[description]", search[description]));
    }
    if(search[name] != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[name]", search[name]));
    }
    if(search[notificationEmailAddress] != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[notificationEmailAddress]", search[notificationEmailAddress]));
    }
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'OrganizationPagination') as OrganizationPagination ;
    } else {
      return null;
    }
  }
  /// Remove one Relationship resource.
  ///
  /// 
  Future<Organization> deleteRelationshipByOrganizationAndRelationship(String xKeyclicApp, String organization, String relationship, { String acceptLanguage, String xKeyclicAppVersion }) async {
    Object postBody = null;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }
    if(relationship == null) {
     throw new ApiException(400, "Missing required param: relationship");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships/{relationship}".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString()).replaceAll("{" + "relationship" + "}", relationship.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'Organization') as Organization ;
    } else {
      return null;
    }
  }
  /// Create one Relationship resource.
  ///
  /// 
  Future<Organization> postRelationshipByOrganization(String xKeyclicApp, RelationshipData relationshipData, String organization, { String acceptLanguage, String xKeyclicAppVersion }) async {
    Object postBody = relationshipData;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(relationshipData == null) {
     throw new ApiException(400, "Missing required param: relationshipData");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'Organization') as Organization ;
    } else {
      return null;
    }
  }
}

==> keyclic_sdk_api-1.28.3.tar.gz: lib/api/relationship_api.dart <==
part of keyclic_sdk_api.api;



class RelationshipApi {
  final ApiClient apiClient;

  RelationshipApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Retrieve all Relationship resources.
  ///
  /// 
  Future<OrganizationPagination> cgetRelationshipsByOrganization(String xKeyclicApp, String organization, { String acceptLanguage, String xKeyclicAppVersion, String businessActivity, String geoCoordinates, String geoPoint, int page, int limit, String order, DateTime after, DateTime before, String search_alternateName_, String search_billingEmailAddress_, String search_description_, String search_name_, String search_notificationEmailAddress_ }) async {
    Object postBody = null;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(businessActivity != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "business_activity", businessActivity));
    }
    if(geoCoordinates != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "geo_coordinates", geoCoordinates));
    }
    if(geoPoint != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "geo_point", geoPoint));
    }
    if(page != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(order != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "order", order));
    }
    if(after != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "after", after));
    }
    if(before != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "before", before));
    }
    if(search_alternateName_ != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[alternateName]", search_alternateName_));
    }
    if(search_billingEmailAddress_ != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[billingEmailAddress]", search_billingEmailAddress_));
    }
    if(search_description_ != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[description]]", search_description_));
    }
    if(search_name_ != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[name]", search_name_));
    }
    if(search_notificationEmailAddress_ != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "search[notificationEmailAddress]", search_notificationEmailAddress_));
    }
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'OrganizationPagination') as OrganizationPagination ;
    } else {
      return null;
    }
  }
  /// Remove one Relationship resource.
  ///
  /// 
  Future<Organization> deleteRelationshipByOrganizationAndRelationship(String xKeyclicApp, String organization, String relationship, { String acceptLanguage, String xKeyclicAppVersion }) async {
    Object postBody = null;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }
    if(relationship == null) {
     throw new ApiException(400, "Missing required param: relationship");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships/{relationship}".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString()).replaceAll("{" + "relationship" + "}", relationship.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'Organization') as Organization ;
    } else {
      return null;
    }
  }
  /// Create one Relationship resource.
  ///
  /// 
  Future<Organization> postRelationshipByOrganization(String xKeyclicApp, RelationshipData relationshipData, String organization, { String acceptLanguage, String xKeyclicAppVersion }) async {
    Object postBody = relationshipData;

    // verify required params are set
    if(xKeyclicApp == null) {
     throw new ApiException(400, "Missing required param: xKeyclicApp");
    }
    if(relationshipData == null) {
     throw new ApiException(400, "Missing required param: relationshipData");
    }
    if(organization == null) {
     throw new ApiException(400, "Missing required param: organization");
    }

    // create path and map variables
    String path = "/organizations/{organization}/relationships".replaceAll("{format}","json").replaceAll("{" + "organization" + "}", organization.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["accept-language"] = acceptLanguage;
headerParams["x-keyclic-app"] = xKeyclicApp;
headerParams["x-keyclic-app-version"] = xKeyclicAppVersion;

    List<String> contentTypes = ["application/json;charset=UTF-8"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'Organization') as Organization ;
    } else {
      return null;
    }
  }
}
